==> vtk6-6.3.0-4-armv6h.pkg.tar.xz: vtk/vtkSliderRepresentation3D.java <==
// java wrapper for vtkSliderRepresentation3D object
//

package vtk;
import vtk.*;

public class vtkSliderRepresentation3D extends vtkSliderRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetPoint1Coordinate_2();
  public vtkCoordinate GetPoint1Coordinate() {
    long temp = GetPoint1Coordinate_2();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetPoint1InWorldCoordinates_3(double id0,double id1,double id2);
  public void SetPoint1InWorldCoordinates(double id0,double id1,double id2)
    { SetPoint1InWorldCoordinates_3(id0,id1,id2); }

  private native long GetPoint2Coordinate_4();
  public vtkCoordinate GetPoint2Coordinate() {
    long temp = GetPoint2Coordinate_4();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetPoint2InWorldCoordinates_5(double id0,double id1,double id2);
  public void SetPoint2InWorldCoordinates(double id0,double id1,double id2)
    { SetPoint2InWorldCoordinates_5(id0,id1,id2); }

  private native void SetTitleText_6(String id0);
  public void SetTitleText(String id0)
    { SetTitleText_6(id0); }

  private native String GetTitleText_7();
  public String GetTitleText()
    { return GetTitleText_7(); }

  private native void SetSliderShape_8(int id0);
  public void SetSliderShape(int id0)
    { SetSliderShape_8(id0); }

  private native int GetSliderShapeMinValue_9();
  public int GetSliderShapeMinValue()
    { return GetSliderShapeMinValue_9(); }

  private native int GetSliderShapeMaxValue_10();
  public int GetSliderShapeMaxValue()
    { return GetSliderShapeMaxValue_10(); }

  private native int GetSliderShape_11();
  public int GetSliderShape()
    { return GetSliderShape_11(); }

  private native void SetSliderShapeToSphere_12();
  public void SetSliderShapeToSphere()
    { SetSliderShapeToSphere_12(); }

  private native void SetSliderShapeToCylinder_13();
  public void SetSliderShapeToCylinder()
    { SetSliderShapeToCylinder_13(); }

  private native void SetRotation_14(double id0);
  public void SetRotation(double id0)
    { SetRotation_14(id0); }

  private native double GetRotation_15();
  public double GetRotation()
    { return GetRotation_15(); }

  private native long GetSliderProperty_16();
  public vtkProperty GetSliderProperty() {
    long temp = GetSliderProperty_16();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetTubeProperty_17();
  public vtkProperty GetTubeProperty() {
    long temp = GetTubeProperty_17();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetCapProperty_18();
  public vtkProperty GetCapProperty() {
    long temp = GetCapProperty_18();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedProperty_19();
  public vtkProperty GetSelectedProperty() {
    long temp = GetSelectedProperty_19();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void PlaceWidget_20(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_20(id0); }

  private native void BuildRepresentation_21();
  public void BuildRepresentation()
    { BuildRepresentation_21(); }

  private native void StartWidgetInteraction_22(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_22(id0); }

  private native void WidgetInteraction_23(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_23(id0); }

  private native void Highlight_24(int id0);
  public void Highlight(int id0)
    { Highlight_24(id0); }

  private native double[] GetBounds_25();
  public double[] GetBounds()
    { return GetBounds_25(); }

  private native void GetActors_26(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_26(id0); }

  private native void ReleaseGraphicsResources_27(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_27(id0); }

  private native int RenderOpaqueGeometry_28(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_28(id0); }

  private native int RenderTranslucentPolygonalGeometry_29(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_29(id0); }

  private native int HasTranslucentPolygonalGeometry_30();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_30(); }

  private native int GetMTime_31();
  public int GetMTime()
    { return GetMTime_31(); }

  public vtkSliderRepresentation3D() { super(); }

  public vtkSliderRepresentation3D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkSliderRepresentation3D.java <==
// java wrapper for vtkSliderRepresentation3D object
//

package vtk;
import vtk.*;

public class vtkSliderRepresentation3D extends vtkSliderRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetPoint1Coordinate_2();
  public vtkCoordinate GetPoint1Coordinate() {
    long temp = GetPoint1Coordinate_2();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPoint1InWorldCoordinates_3(double id0,double id1,double id2);
  public void SetPoint1InWorldCoordinates(double id0,double id1,double id2)
    { SetPoint1InWorldCoordinates_3(id0,id1,id2); }

  private native long GetPoint2Coordinate_4();
  public vtkCoordinate GetPoint2Coordinate() {
    long temp = GetPoint2Coordinate_4();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPoint2InWorldCoordinates_5(double id0,double id1,double id2);
  public void SetPoint2InWorldCoordinates(double id0,double id1,double id2)
    { SetPoint2InWorldCoordinates_5(id0,id1,id2); }

  private native void SetTitleText_6(String id0);
  public void SetTitleText(String id0)
    { SetTitleText_6(id0); }

  private native String GetTitleText_7();
  public String GetTitleText()
    { return GetTitleText_7(); }

  private native void SetSliderShape_8(int id0);
  public void SetSliderShape(int id0)
    { SetSliderShape_8(id0); }

  private native int GetSliderShapeMinValue_9();
  public int GetSliderShapeMinValue()
    { return GetSliderShapeMinValue_9(); }

  private native int GetSliderShapeMaxValue_10();
  public int GetSliderShapeMaxValue()
    { return GetSliderShapeMaxValue_10(); }

  private native int GetSliderShape_11();
  public int GetSliderShape()
    { return GetSliderShape_11(); }

  private native void SetSliderShapeToSphere_12();
  public void SetSliderShapeToSphere()
    { SetSliderShapeToSphere_12(); }

  private native void SetSliderShapeToCylinder_13();
  public void SetSliderShapeToCylinder()
    { SetSliderShapeToCylinder_13(); }

  private native void SetRotation_14(double id0);
  public void SetRotation(double id0)
    { SetRotation_14(id0); }

  private native double GetRotation_15();
  public double GetRotation()
    { return GetRotation_15(); }

  private native long GetSliderProperty_16();
  public vtkProperty GetSliderProperty() {
    long temp = GetSliderProperty_16();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTubeProperty_17();
  public vtkProperty GetTubeProperty() {
    long temp = GetTubeProperty_17();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCapProperty_18();
  public vtkProperty GetCapProperty() {
    long temp = GetCapProperty_18();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedProperty_19();
  public vtkProperty GetSelectedProperty() {
    long temp = GetSelectedProperty_19();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void PlaceWidget_20(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_20(id0); }

  private native void BuildRepresentation_21();
  public void BuildRepresentation()
    { BuildRepresentation_21(); }

  private native void StartWidgetInteraction_22(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_22(id0); }

  private native void WidgetInteraction_23(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_23(id0); }

  private native void Highlight_24(int id0);
  public void Highlight(int id0)
    { Highlight_24(id0); }

  private native double[] GetBounds_25();
  public double[] GetBounds()
    { return GetBounds_25(); }

  private native void GetActors_26(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_26(id0); }

  private native void ReleaseGraphicsResources_27(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_27(id0); }

  private native int RenderOpaqueGeometry_28(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_28(id0); }

  private native int RenderTranslucentPolygonalGeometry_29(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_29(id0); }

  private native int HasTranslucentPolygonalGeometry_30();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_30(); }

  private native int GetMTime_31();
  public int GetMTime()
    { return GetMTime_31(); }

  private native void RegisterPickers_32();
  public void RegisterPickers()
    { RegisterPickers_32(); }

  public vtkSliderRepresentation3D() { super(); }

  public vtkSliderRepresentation3D(long id) { super(id); }
  public native long   VTKInit();

}
